@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1381 2022/03/29 18:31:13 sdk Exp $
+# $OpenBSD: Quirks.pm,v 1.1516.2.2 2023/10/02 21:46:36 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -26,14 +26,14 @@ package OpenBSD::Quirks;
 sub new
 {
 	my ($class, $version) = @_;
-	if ($version <= 4) {
-		return OpenBSD::Quirks4->new;
+	if ($version <= 5) {
+		return OpenBSD::Quirks5->new;
 	} else {
 		return undef;
 	}
 }
 
-package OpenBSD::Quirks4;
+package OpenBSD::Quirks5;
 use Config;
 sub new
 {
@@ -495,7 +495,7 @@ my $stem_extensions = {
 	'py-websocket-client' => 'py3-websocket-client',
 	'libmesode' => 'libstrophe',
 	'py-stem' => 'py3-stem',
-# 7.1	    
+# 7.1
 	'py-jsonschema' => 'py3-jsonschema',
 	'py-CherryPy' => 'py3-CherryPy',
 	'py-IP' => 'py3-IP',
@@ -566,7 +566,6 @@ my $stem_extensions = {
 	'py-waitress' => 'py3-waitress',
 	'py-webencodings' => 'py3-webencodings',
 	'py-xmltodict' => 'py3-xmltodict',
-	'py-zc-lockfilezc.lockfile' => 'py3-zc-lockfilezc.lockfile',
 	'py-jaraco-functools' => 'py3-jaraco-functools',
 	'py-logilab-common' => 'py3-logilab-common',
 	'py-memcached' => 'py3-memcached',
@@ -720,6 +719,62 @@ my $stem_extensions = {
 	'py-pretend' => 'py3-pretend',
 	'py-mock' => 'py3-mock',
 	'gmic-qt-krita' => 'krita-gmic-plugin',
+# 7.2
+	'tracker-miners' => 'tracker3-miners',
+	'tracker' => 'tracker3',
+	'libgweather' => 'libgweather4',
+	'spidermonkey78' => 'spidermonkey91',
+	'gmime' => 'gmime30',
+	'fcitx-pinyin' => 'fcitx-chinese-addons',
+	'py-quixote' => 'py3-quixote',
+	'py-requests' => 'py3-requests',
+	'py-chardet' => 'py3-chardet',
+	'chrome-gnome-shell' => 'gnome-browser-connector',
+	'tdesktop-qt6' => 'tdesktop',
+	'blocksruntime' => 'libdispatch',
+	'py-mongo' => 'py3-mongo',
+	'py-wheel' => 'py3-wheel',
+	'py-idna' => 'py3-idna',
+	'py-urllib3' => 'py3-urllib3',
+	'py-packaging' => 'py3-packaging',
+	'py-certifi' => 'py3-certifi',
+	'py-ecdsa' => 'py3-ecdsa',
+	'py-virtualenv' => 'py3-virtualenv',
+	'webkitgtk4' => 'webkitgtk40',
+	'py-llvmlite' => 'py3-llvmlite',
+	'py-dpkt' => 'py3-dpkt',
+	'py-dbus' => 'py3-dbus',
+	'dspy' => 'd-spy',
+	'i3-mousedrag' => 'i3',
+# 7.3
+	'spidermonkey91' => 'spidermonkey102',
+	'dleyna-core' => 'dleyna',
+	'gnome-todo' => 'endeavour',
+	'go-ipfs' => 'kubo',
+	'py-zc-lockfilezc.lockfile' => 'py3-zc-lockfile',
+	'py3-zc-lockfilezc.lockfile' => 'py3-zc-lockfile',
+	'py-elfesteem' => 'py3-miasm', # merged
+	'py-miasm' => 'py3-miasm',
+	'py-cssselect' => 'py3-cssselect',
+	'py-cparser' => 'py3-cparser',
+	'py-authres' => 'py3-authres',
+	'py-policyd-spf' => 'py3-policyd-spf',
+	'py-spf' => 'py3-spf',
+	'py-nose' => 'py3-nose',
+	'py-xdg' => 'py3-xdg',
+	'i3-gaps' => 'i3',
+	'rebar' => 'rebar3',
+	'gortr' => 'stayrtr',
+	'py-wxPython' => 'py3-wxPython',
+	'py-modulegraph' => 'py3-modulegraph',
+	'py-psutil' => 'py3-psutil',
+	'py-lxml' => 'py3-lxml',
+	'py-pyglet' => 'py3-pyglet',
+	'py-suds' => 'py3-suds',
+	'py-serial' => 'py3-serial',
+	'py3-wxPython-webkit' => 'py3-wxPython-webview',
+	'wxWidgets-webkit' => 'wxWidgets-webview',
+	'ring' => 'rust-ring',
 };
 
 my $obsolete_reason = {};
@@ -746,7 +801,6 @@ setup_obsolete_reason(
 	6 => 'empathy',
 	3 => 'telepathy-salut',
 	3 => 'telepthy-haze',
-	3 => 'telepathy-idle',
 	3 => 'telepathy-gabble',
 	3 => 'telepathy-qt',
 	3 => 'telepathy-farstream',
@@ -1301,7 +1355,7 @@ setup_obsolete_reason(
 	0 => 'lazarus',
 	13 => 'exaile',
 	3 => 'instead-launcher',
-	3 => qr{^(ruby(19|2[0-6])-|ruby-[^0-9])},
+	3 => qr{^(ruby(19|2[0-7])-|^ruby-[^0-9])},
 # 6.9
 	3 => 'py-notify',
 	3 => 'glimpse',
@@ -1332,9 +1386,7 @@ setup_obsolete_reason(
 	5 => 'gnome-getting-started-docs',
 	3 => 'py-poppler',
 	3 => 'pdfshuffler',
-	27 => 'colord',
 	27 => 'colord-gtk',
-	5 => 'gnome-color-manager',
 	3 => 'zeya',
 	3 => 'py-trollius',
 	3 => qr{^kde-i18n-},
@@ -1355,7 +1407,6 @@ setup_obsolete_reason(
 	3 => 'qt3-sqlite2',
 	6 => 'gtk3mm-documentation',
 	5 => 'libxml++3',
-	3 => 'orage',
 	3 => 'xfce4-statusnotifier',
 	3 => 'pylint3-gui',
 	3 => 'e_dbus',
@@ -1662,6 +1713,107 @@ setup_obsolete_reason(
 	31 => 'py-ipaddress',
 	31 => 'py-scandir',
 	3 => 'd-feet',
+# 7.2
+	3 => 'gnome-documents',
+	3 => 'lumail',
+	3 => 'kalarmcal',
+	5 => 'gnats',
+	3 => 'gnome-books',
+	46 => 'go-bootstrap',
+	31 => 'py-typing',
+	6 => 'py-funcsigs',
+	6 => 'py-statistics',
+	31 => 'pyrex',
+	3 => 'luasoldout',
+	3 => 'honeyd',
+	47 => 'totd',
+	6 => 'py3-importlib_resources',
+	3 => 'py3-uv',
+	6 => 'py3-blist',
+	6 => 'mlt',
+	6 => 'mlt-gpl',
+	6 => 'webvfx',
+	6 => 'libXp',
+	5 => 'gamin',
+	6 => 'py-futures',
+	0 => 'p5-Crypt-Serpent',
+	5 => 'compiz-bcop',
+	5 => 'ccsm',
+	5 => 'compizconfig-python',
+	5 => 'compiz',
+	5 => 'libcompizconfig',
+	5 => 'compiz-plugins-main',
+	5 => 'usrsctp',
+	0 => 'shapezio',
+	3 => 'boar',
+# 7.3
+	3 => 'evolution-rss',
+	3 => 'libgfbgraph',
+	3 => 'gnome-online-miners',
+	3 => 'libzapojit',
+	3 => 'librest',
+	3 => 'seahorse-sharing',
+	48 => 'electron',
+	3 => 'xalan-c',
+	5 => 'xalan-j',
+	5 => 'opencdk',
+	5 => 'klaxon',
+	49 => 'sentinel',
+	50 => 'sslScanner',
+	5 => 'softhsm',
+	1 => 'chntpw',
+	5 => 'nbaudit',
+	1 => 'despoof',
+	51 => 'zebedee',
+	3 => 'slurpie',
+	1 => 'samdump2',
+	1 => 'smbsniff',
+	0 => 'fragroute',
+	52 => 'ikeman',
+	3 => 'libperseus',
+	0 => 'hatchet',
+	51 => 'ctunnel',
+	3 => 'py-libpcap',
+	3 => 'supybot',
+	3 => 'dissy',
+	1 => 'stm32loader',
+	3 => 'tmda',
+	3 => 'spambayes',
+	31 => 'nmap-zenmap',
+	0 => 'uucpd',
+	6 => 'py-sqlite2',
+	31 => 'py-ipaddr',
+	3 => 'hlfl',
+	6 => 'caribou',
+	5 => 'riak',
+	15 => 'rmilter',
+	3 => 'gotweb',
+	6 => 'go-net',
+	6 => 'go-goptlib',
+	0 => 'xco',
+	6 => 'go-sys',
+	6 => 'go-crypto',
+	6 => 'go-ed25519',
+	6 => 'go-siphash',
+	6 => 'go-text',
+	6 => 'cryptcat',
+	6 => 'pilot-link',
+	6 => 'jpilot',
+	3 => 'midori',
+	3 => 'pykaraoke',
+	3 => 'sk1',
+	0 => 'pgadmin3',
+	3 => 'rapidsvn',
+	0 => 'chbg',
+	3 => 'wammu',
+	3 => 'winwrangler',
+	3 => 'gtkhotkey',
+	3 => 'libwnck',
+	6 => 'ap-utils',
+	6 => 'kibana',
+	6 => 'elasticsearch',
+	3 => 'ogmrip',
+	3 => 'shrip',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
@@ -1678,6 +1830,7 @@ my $obsolete_suggestion = {
 	'keepassx' => 'keepassxc',
 	'lives' => [qw(kdenlive shotcut)],
 	'pdfshuffler' => 'pdfarranger',
+	'gotweb' => 'gotwebd',
 };
 
 # reasons for obsolete packages
@@ -1697,6 +1850,7 @@ my $obsolete_message = {
 	12 => "replace with IMAPSieve, see https://wiki.dovecot.org/HowTo/AntispamWithSieve",
 	13 => "has a dependency on obsolete software",
 	14 => "no longer maintained upstream and has security issues, consider remmina or tigervnc's vncviewer as an alternative",
+	15 => "use rspamd's internal milter support instead",
 	17 => "old GeoIP databases end-of-life, see alternative using geoip2/libmaxminddb",
 	20 => "merged into IETF Opus codec, obsolete, audio/mumble uses bundled version now",
 	21 => "upstream recommends to use composer to build a drupal site",
@@ -1720,6 +1874,13 @@ my $obsolete_message = {
 	43 => "using portgen instead is recommended",
 	44 => "qucs-s Qt4 UI not working correctly, suggest xschem or kicad's eeschema instead",
 	45 => "crashes in many different ways at runtime",
+	46 => "moved to binary bootstraps",
+	47 => "DNS network daemon running as root and not using random source ports. use DNS64 support in unbound or isc-bind",
+	48 => "horrible ecosystem",
+	49 => "has no license, unmaintained since too long, crashes at runtime",
+	50 => "abandoned ten years ago, broken by default due to missing runtime dependencies, use security/sslscan",
+	51 => "dead upstream, consider using socat or SSH",
+	52 => "unmaintained since import, already on LibreSSL life support for too long",
 };
 
 # ->is_base_system($handle, $state):
@@ -1803,14 +1964,25 @@ sub tweak_search
 		return;
 	}
 	my $stem = OpenBSD::PackageName::splitstem($handle->pkgname);
+	$self->may_add_stems($l->[0], $stem, $state);
+}
+
+# ->may_add_stems($object, $stem, $state):
+# 	may add stems to an object using $object->add_stem
+#	based on a given stem.
+
+sub may_add_stems
+{
+	my ($self, $object, $stem, $state) = @_;
+
 	my $extra = $stem_extensions->{$stem};
 	if (defined $extra) {
 		if (ref $extra) {
 			for my $e (@$extra) {
-				$l->[0]->add_stem($e);
+				$object->add_stem($e);
 			}
 		} else {
-			$l->[0]->add_stem($extra);
+			$object->add_stem($extra);
 		}
 	}
 }
@@ -1830,9 +2002,10 @@ my $cve = {
 	'databases/postgresql,-server' => 'postgresql-server-<10.6',
 	'databases/sqlite3' => 'sqlite3-<3.25.3',
 	'devel/apache-ant' => 'apache-ant-<1.10.9',
-	'devel/git,-main' => 'git-<2.30.2',
-	'devel/git,-svn' => 'git-svn-<2.30.2',
-	'devel/git,-x11' => 'git-x11-<2.30.2',
+	'devel/git,-main' => 'git-<2.35.2',
+	'devel/git,-svn' => 'git-svn-<2.35.2',
+	'devel/git,-x11' => 'git-x11-<2.35.2',
+	'devel/jansson' => 'jansson-<2.14',
 	'devel/jenkins/devel' => 'jenkins-<2.154',
 	'devel/jenkins/stable' => 'jenkins-<2.138.4',
 	'devel/libgit2/libgit2' => 'libgit2-<0.27.7',
@@ -1856,7 +2029,6 @@ my $cve = {
 	'lang/ruby/2.5,-main' => 'ruby->2.5,<2.5.5',
 	'lang/ruby/2.6,-main' => 'ruby->2.6,<2.6.2',
 	'mail/dovecot,-server' => 'dovecot-<2.3.10.1',
-	'mail/exim' => 'exim-<4.83',
 	'mail/isync' => 'isync-<1.4.4',
 	'mail/mailman' => 'mailman-<2.1.30',
 	'mail/p5-Mail-SpamAssassin' => 'p5-Mail-SpamAssassin-<3.4.4',
@@ -1903,6 +2075,7 @@ my $cve = {
 	'security/sudo' => 'sudo-<1.8.31',
 	'shells/bash' => 'bash-<4.3.27',
 	'sysutils/ansible,-main' => 'ansible-<2.7.1',
+	'sysutils/borgbackup/1.2' => 'borgbackup-<1.2.5',
 	'sysutils/mcollective' => 'mcollective-<2.5.3',
 	'sysutils/rclone' => 'rclone-<1.53.3',
 	'sysutils/salt' => 'salt-<3002',
@@ -1940,6 +2113,7 @@ my $cve = {
 	'www/webkitgtk4' => 'webkitgtk4-<2.20.5',
 	'x11/gnome/gdm' => 'gdm-<3.28.3',
 	'x11/rdesktop' => 'rdesktop-<1.8.4',
+	'mail/exim,-main' => 'exim-<4.97',
 };
 # please maintain sort order in above $cve list, future updates need to
 # replace existing entries
